==> devextreme-23.1.12-build-24182-0109.tgz: package/cjs/ui/html_editor/converters/delta.js <==
/**
 * DevExtreme (cjs/ui/html_editor/converters/delta.js)
 * Version: 23.1.11 (build 24182-0109)
 * Build date: Sun Jun 30 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _converterController = _interopRequireDefault(require("../converterController"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
var DeltaConverter = function() {
    function DeltaConverter() {}
    var _proto = DeltaConverter.prototype;
    _proto.setQuillInstance = function(quillInstance) {
        this.quillInstance = quillInstance
    };
    _proto.toHtml = function() {
        if (!this.quillInstance) {
            return
        }
        return this._isQuillEmpty() ? "" : this.quillInstance.getSemanticHTML(0, this.quillInstance.getLength() + 1)
    };
    _proto._isQuillEmpty = function() {
        var delta = this.quillInstance.getContents();
        return 1 === delta.length() && this._isDeltaEmpty(delta)
    };
    _proto._isDeltaEmpty = function(delta) {
        return delta.reduce((function(__, _ref) {
            var insert = _ref.insert;
            return -1 !== insert.indexOf("\n")
        }))
    };
    return DeltaConverter
}();
_converterController.default.addConverter("delta", DeltaConverter);
var _default = DeltaConverter;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-23.2.4-build-24021-0112.tgz: package/cjs/ui/html_editor/converters/delta.js <==
/**
 * DevExtreme (cjs/ui/html_editor/converters/delta.js)
 * Version: 23.2.3 (build 24021-0112)
 * Build date: Sun Jan 21 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _converterController = _interopRequireDefault(require("../converterController"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
let DeltaConverter = function() {
    function DeltaConverter() {}
    var _proto = DeltaConverter.prototype;
    _proto.setQuillInstance = function(quillInstance) {
        this.quillInstance = quillInstance
    };
    _proto.toHtml = function() {
        if (!this.quillInstance) {
            return
        }
        return this._isQuillEmpty() ? "" : this.quillInstance.getSemanticHTML(0, this.quillInstance.getLength() + 1)
    };
    _proto._isQuillEmpty = function() {
        const delta = this.quillInstance.getContents();
        return 1 === delta.length() && this._isDeltaEmpty(delta)
    };
    _proto._isDeltaEmpty = function(delta) {
        return delta.reduce((__, _ref) => {
            let {
                insert: insert
            } = _ref;
            return -1 !== insert.indexOf("\n")
        })
    };
    return DeltaConverter
}();
_converterController.default.addConverter("delta", DeltaConverter);
var _default = DeltaConverter;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;
